==> arkade-modules-1.0.2.tgz: package/index.js <==

module.exports = class arkade{
  constructor(token , obj  , message){
    this.token=token;
    this.obj=obj;
  }
    async createHandler(){
      const fs = require('fs');
      const Discord = require('discord.js');
      // const confisg = require('.');
    
      require('dotenv').config();
      const client = new Discord.Client();
      client.commands = new Discord.Collection();
      client.cooldowns = new Discord.Collection();
      let prefix;
      const commandFolders = fs.readdirSync('./commands');
      for (const folder of commandFolders) {
        const commandFiles = fs.readdirSync(`./commands/${folder}`).filter(file => file.endsWith('.js'));
        for (const file of commandFiles) {
          const command = require(`../../commands/${folder}/${file}`);
          client.commands.set(command.name, command);
        }
      }
      
      client.once('ready', () => {
        console.log('Ready!');
      });
      
      client.on('message', message => {
        // this.message = message;
        module.exports = message;
        let mentionRegex = message.content.match(new RegExp(`^<@!?(${client.user.id})>` , "gi"))
        if(mentionRegex){
          prefix = `${mentionRegex[0]}`
        } 
        else{
          prefix = this.obj.prefix;
        }
        if (!message.content.startsWith(prefix) || message.author.bot) return;
      
        const args = message.content.slice(prefix.length).trim().split(/ +/);
        const commandName = args.shift().toLowerCase();
      
        const command = client.commands.get(commandName)
          || client.commands.find(cmd => cmd.aliases && cmd.aliases.includes(commandName));
      
        if (!command) return;
      
        if (command.guildOnly && message.channel.type === 'dm') {
          return message.reply('I can\'t execute that command inside DMs!');
        }
      
        if (command.permissions) {
          const authorPerms = message.channel.permissionsFor(message.author);
          if (!authorPerms || !authorPerms.has(command.permissions)) {
            return message.reply('You can not do this!');
          }
        }
      
      
        if (command.args && !args.length) {
          let reply = `You didn't provide any arguments, ${message.author}!`;
      
          if (command.usage) {
            reply += `\nThe proper usage would be: \`${prefix}${command.name} ${command.usage}\``;
          }
      
          return message.channel.send(reply);
        }
        if(this.obj.cooldown===true || this.obj.cooldown === null){
      
        const { cooldowns } = client;
      
        if (!cooldowns.has(command.name)) {
          cooldowns.set(command.name, new Discord.Collection());
        }
      
        const now = Date.now();
        const timestamps = cooldowns.get(command.name);
        const cooldownAmount = (command.cooldown || 3) * 1000;
      
        if (timestamps.has(message.author.id)) {
          const expirationTime = timestamps.get(message.author.id) + cooldownAmount;
      
          if (now < expirationTime) {
            const timeLeft = (expirationTime - now) / 1000;
            return message.reply(`please wait ${timeLeft.toFixed(1)} more second(s) before reusing the \`${command.name}\` command.`);
          }
        }
      
        timestamps.set(message.author.id, now);
        setTimeout(() => timestamps.delete(message.author.id), cooldownAmount);
      }
        module.exports=message;
      
        try {
          command.run(message, args , client);
          }
          
         catch (error) {
          console.error(error);
          message.reply('there was an error trying to execute that command!');
        }
      });
      client.login(this.token);
      
    }
    async createReactionPages(pages , message){
      // console.log(msg())
      // console.log(message.content)
      if(Array.isArray(pages) === false )return console.log("Reaction Pages must be an array")
      let index = 0
      let home = pages[index]
      let msg = await message.channel.send(home)
      await msg.react('⏪')
      await msg.react('⏩')
    
      const backwards = (reaction , user) => reaction.emoji.name === "⏪" && user.id === message.author.id
      const forwards = (reaction , user) => reaction.emoji.name === "⏩" && user.id === message.author.id
      let pager =  await message.channel.send(`Pages ${index + 1 } of ${pages.length}`)
     
      const backCreate = msg.createReactionCollector(backwards , {dispose: true})
          backCreate.on("collect" , r => {
            r.users.remove(message.author.id);
            if(index > 0){
            index--;
            msg.edit(pages[index]);
              pager.edit(`Pages ${index + 1 } of ${pages.length}`);
              }
            console.log(index);
          })
          const forwardCreate = msg.createReactionCollector(forwards , {dispose: true})
          forwardCreate.on("collect" , r => {
            r.users.remove(message.author.id);
            if(index < pages.length-1){
            index++;
            msg.edit(pages[index]);
            pager.edit(`Pages ${index + 1 } of ${pages.length}`);
            }
          })

    }
    async createReactionCollector(ogmessage, emojis , tosend  , message , handleROLE , funcArray){
  if(Array.isArray(emojis) === false)return console.log("Emojis Must be an array");
if(ogmessage===undefined ||emojis===undefined ||tosend===undefined)return message.channel.send("Please specify all nessecary values");
if(Array.isArray(emojis) === false || Array.isArray(tosend) ===false)return console.log("Emojis and Tosend parameters must be an array")
if(emojis.length !== tosend.length)return console.log("Please Specifiy the correct number of responses as per the emojis")

console.log(Array.isArray(emojis))
let msg = await message.channel.send(ogmessage);
emojis.forEach(async function(emoji){
try{
await msg.react(emoji);
const sure = (reaction , user) => reaction.emoji.name === emoji && user.id === message.author.id
const sureCreate = msg.createReactionCollector(sure , {dispose: true})
    sureCreate.on("collect" , r => {
      r.users.remove(message.author.id)
      message.channel.send(tosend[emojis.indexOf(emoji)])
      let index =emojis.indexOf(emoji);
      if(funcArray !== undefined){
      funcArray[index]();}
      if(handleROLE !==undefined){
        try{
          var role= message.member.guild.roles.cache.find(role => role.name === handleROLE);
         }
        catch(e){
         message.channel.send("INVALID ROLE")
         }
         if(role!==undefined){
          message.member.roles.add(role);
         }
         else{
           message.channel.send("INVALID ROLE")
         }    
      }
    })
  
}
catch(e){
  console.log('Invalid Emoji')
}
})


    }
 
    

}

==> arkade-modules-1.0.4.tgz: package/index.js <==
const message = require('arkade-modules');

module.exports = class arkade{
  constructor(token , obj ){
    this.token=token;
    this.obj=obj;
    this.default = false;
  }

  async loadDefault(object){
    this.default = true;
    this.object=object;
  }
    async createHandler(){
      console.log(this.default)
      const fs = require('fs');
      const Discord = require('discord.js');
      // const confisg = require('.');
    
      require('dotenv').config();
       const client = new Discord.Client();
      client.commands = new Discord.Collection();
      client.cooldowns = new Discord.Collection();
      let prefix;
      const commandFolders = fs.readdirSync('./commands');
      for (const folder of commandFolders) {
        const commandFiles = fs.readdirSync(`./commands/${folder}`).filter(file => file.endsWith('.js'));
        for (const file of commandFiles) {
          const command = require(`../../commands/${folder}/${file}`);
          client.commands.set(command.name, command);
        }
      }
      
      client.once('ready', () => {
        console.log('Ready!');
      });
      if(this.obj.serverJoin !==undefined) {
      var channelToSend = this.obj.channel;
      client.on('guildCreate', (guild) => {  
        let channel = client.channels.cache.get(channelToSend);
        channel.send(this.obj.serverJoin)
        // console.log(this.serverJoin);
      });


    }

      
      client.on('message', message => {
        // this.message = message;
        module.exports = message;
        let mentionRegex = message.content.match(new RegExp(`^<@!?(${client.user.id})>` , "gi"))
        if(mentionRegex){
          prefix = `${mentionRegex[0]}`
        } 
        else{
          prefix = this.obj.prefix;
        }
        if (!message.content.startsWith(prefix) || message.author.bot) return;
      
        var args = message.content.slice(prefix.length).trim().split(/ +/);
        const commandName = args.shift().toLowerCase();
      
        const command = client.commands.get(commandName)
          || client.commands.find(cmd => cmd.aliases && cmd.aliases.includes(commandName));
      
        if (!command) return;
      
        if (command.guildOnly && message.channel.type === 'dm') {
          return message.reply('I can\'t execute that command inside DMs!');
        }
      
        if (command.permissions) {
          const authorPerms = message.channel.permissionsFor(message.author);
          if (!authorPerms || !authorPerms.has(command.permissions)) {
            return message.reply('You can not do this!');
          }
        }
      
      
        if (command.args && !args.length) {
          let reply = `You didn't provide any arguments, ${message.author}!`;
      
          if (command.usage) {
            reply += `\nThe proper usage would be: \`${prefix}${command.name} ${command.usage}\``;
          }
      
          return message.channel.send(reply);
        }
        if(this.obj.cooldown===true || this.obj.cooldown === null){
      
        const { cooldowns } = client;
      
        if (!cooldowns.has(command.name)) {
          cooldowns.set(command.name, new Discord.Collection());
        }
      
        const now = Date.now();
        const timestamps = cooldowns.get(command.name);
        const cooldownAmount = (command.cooldown || 3) * 1000;
      
        if (timestamps.has(message.author.id)) {
          const expirationTime = timestamps.get(message.author.id) + cooldownAmount;
      
          if (now < expirationTime) {
            const timeLeft = (expirationTime - now) / 1000;
            return message.reply(`please wait ${timeLeft.toFixed(1)} more second(s) before reusing the \`${command.name}\` command.`);
          }
        }
      
        timestamps.set(message.author.id, now);
        setTimeout(() => timestamps.delete(message.author.id), cooldownAmount);
      }
        module.exports=message;
        if(this.default === true){
          console.log(this.object.reload)
        if(this.object.reload === false) return;

          if(message.content === `${this.obj.prefix}reload`){

          if(!args[0])return message.channel.send("Mention which category to reload")
         if(!args[1])return message.channel.send("Mention which command to reload")
  
      let commande = args[1];
      let category = args[0]
      try{
        delete require.cache[require.resolve(`../../commands/${category}/${commande}.js`)]
        client.commands.delete(commande)
        const pull = require(`../../commands/${category}/${commande}.js`)
        client.commands.set(commande , pull)
        return message.channel.send(`Successfully reloaded ${commande}` + '.js')
      }catch(error){return message.channel.send("Error! " + error.message)}
          
        }
      }
  
        try {
          command.run(message, args , client);
          }
          
         catch (error) {
          console.error(error);
          message.reply('there was an error trying to execute that command!');
        }
      });
      client.login(this.token);
    }
    async createReactionPages(pages , message){
      // console.log(msg())
      // console.log(message.content)
      if(Array.isArray(pages) === false )return console.log("Reaction Pages must be an array")
      let index = 0
      let home = pages[index]
      let msg = await message.channel.send(home)
      await msg.react('⏪')
      await msg.react('⏩')
    
      const backwards = (reaction , user) => reaction.emoji.name === "⏪" && user.id === message.author.id
      const forwards = (reaction , user) => reaction.emoji.name === "⏩" && user.id === message.author.id
      let pager =  await message.channel.send(`Pages ${index + 1 } of ${pages.length}`)
     
      const backCreate = msg.createReactionCollector(backwards , {dispose: true})
          backCreate.on("collect" , r => {
            r.users.remove(message.author.id);
            if(index > 0){
            index--;
            msg.edit(pages[index]);
              pager.edit(`Pages ${index + 1 } of ${pages.length}`);
              }
            console.log(index);
          })
          const forwardCreate = msg.createReactionCollector(forwards , {dispose: true})
          forwardCreate.on("collect" , r => {
            r.users.remove(message.author.id);
            if(index < pages.length-1){
            index++;
            msg.edit(pages[index]);
            pager.edit(`Pages ${index + 1 } of ${pages.length}`);
            }
          })

    }
    async createReactionCollector(ogmessage, emojis , tosend  , message , handleROLE , funcArray){
  if(Array.isArray(emojis) === false)return console.log("Emojis Must be an array");
if(ogmessage===undefined ||emojis===undefined ||tosend===undefined)return message.channel.send("Please specify all nessecary values");
if(Array.isArray(emojis) === false || Array.isArray(tosend) ===false)return console.log("Emojis and Tosend parameters must be an array")
if(emojis.length !== tosend.length)return console.log("Please Specifiy the correct number of responses as per the emojis")

console.log(Array.isArray(emojis))
let msg = await message.channel.send(ogmessage);
emojis.forEach(async function(emoji){
try{
await msg.react(emoji);
const sure = (reaction , user) => reaction.emoji.name === emoji && user.id === message.author.id
const sureCreate = msg.createReactionCollector(sure , {dispose: true})
    sureCreate.on("collect" , r => {
      r.users.remove(message.author.id)
      message.channel.send(tosend[emojis.indexOf(emoji)])
      let index =emojis.indexOf(emoji);
      if(funcArray !== undefined){
      funcArray[index]();}
      if(handleROLE !==undefined){
        try{
          var role= message.member.guild.roles.cache.find(role => role.name === handleROLE);
         }
        catch(e){
         message.channel.send("INVALID ROLE")
         }
         if(role!==undefined){
          message.member.roles.add(role);
         }
         else{
           message.channel.send("INVALID ROLE")
         }    
      }
    })
  
}
catch(e){
  console.log('Invalid Emoji')
}
})}
 
  }
